// FILENAME:	CTF_Circular_Logic.cs
//
// AUTHORS:  	Cupie Doll & Youth in Asia
//------------------------------------------------------------------------------

$missionName = "OCC_Omega_Construct";

exec("multiplayerStdLib.cs");
exec("DMstdLib.cs");

$killPoints 	= 3;
$deathPoints 	= 2;
$occPoints		= 2;		// Points per 30 seconds of occupation
$occKillPoints	= 7;		// Extra Points for killing the occupier (added to $killPoints)
$fortowner = "";

function player::onAdd(%this)
{
   say(%this, 0, "Welcome to " @ $missionName @ "!  <F5>NOTE:<F0> Read the <F2>?<F0> tab for rules.");
}

function vehicle::onAdd(%vehicleId)
{
	%player = playerManager::vehicleIdToPlayerNum(%vehicleId);

	%team = getTeam(%vehicleId);
	if(%team == *IDSTR_TEAM_RED) %pcolor = "RED";
	if(%team == *IDSTR_TEAM_BLUE) %pcolor = "BLUE";

	%player.name = getHUDName(%vehicleId);
	if(!%player.occPoints) %player.occPoints = 0;
	if(!%player.occKills) %player.occKills = 0;

	// Ensure that occPoints and occKills stay with the player if they switch teams...

	if(%pcolor != %player.color) {
	   %player.color = %pcolor;
	   if(%pcolor == "RED") {
  		$redBonus += %player.occPoints;
		$blueBonus -= %player.occPoints;
		$red_occKills += %player.occKills;
		$blue_occKills -= %player.occKills;
		}
	   else {
		$redBonus -= %player.occPoints;
		$blueBonus += %player.occPoints;
		$redoccKills -= %player.occKills;
		$blueoccKills += %player.occKills;
	   }
	}
}

function setDefaultMissionOptions()
{
	$server::TeamPlay = false;
	$server::AllowDeathmatch = false;
	$server::AllowTeamPlay = true;	

   // what can the client choose for a team
	$server::AllowTeamRed = true;
	$server::AllowTeamBlue = true;
	$server::AllowTeamYellow = false;
	$server::AllowTeamPurple = false;

   // what can the server admin choose for available teams
   $server::disableTeamRed = false;
   $server::disableTeamBlue = false;
   $server::disableTeamYellow = true;
   $server::disableTeamPurple = true;
}

function onMissionStart()
{
	initGlobalVars();

	$redBonus = 0;
	$blueBonus = 0;

	$redTK = 0;
	$blueTK = 0;

	$redoccKills = 0;
	$blueoccKills = 0;

	$healRate = 300;   
	$ammoRate = 10;
   	$padWaitTime = 30;
  	$zenWaitTime = 60;

	titanSounds();
}

function onMissionLoad(){
   cdAudioCycle("Purge", "Terror", "Watching"); 
}

function setRules()
{
      %rules = "<F2>GAME TYPE: \n<F0>Occupation.\n\n"   @        
               "<tIDMULT_TDM_MAPNAME>"    @ 
               $missionName             @
               "\n\n<F2>RULES/OBJECTIVES:\n" @
               "<F0>1) Occupy the Omega Construct and destroy the enemy.\n" @
               "2) Turrets are indestructible: Therefore, destroy the Occupier of the Construct!\n"@
               "3) Only one player can occupy the Construct at a time.\n\n"@
               "<tIDMULT_TDM_SCORING_1>"  @ 
               "<F0>Kills are worth " @ $killPoints @ " points, deaths are worth -" @ $deathPoints @ " points.\n" @
               "Occupiers of the Construct receive " @ $occPoints @ " points every 30 seconds.\n" @
               "Killing the Occupier of the Construct is worth " @ $occKillPoints @ " points.\n\n" @
               "<F2>SERVER RULES/INFORMATION:\n"      @ 
               "<F0>1) All weapons are LEGAL.\n" @
		   "2) Padkilling is LEGAL, particularly if you heal on an enemies pad.\n" @
		   "3) Complaining about items 1 or 2 is ILLEGAL!  Deal with it!  Adapt!  Destroy!\n" @
		   "4) This map was made by Temujin.  You can download it from his website\n" @
 		   "   at http://www6.50megs.com/temujin.  Also at that site is a comprehensive\n" @
		   "   StarSiege training manual and Temujins skin collections.\n\n";

   setGameInfo(%rules);      
}

// setup the rules - this has to be called after the definition of setRules
setRules();



// Fortification Functionality
//------------------------------------------------------------------------------



function Fortify::trigger::OnEnter(%this, %object)
{
	if($fortowner && %object!= $fortowner) {
		say("everybody", 0, getHudName(%object) @ " is ejected from the Omega Construct!", "sfx_had.WAV");
		rejectvehicle(%object);
		return 0;
		}
	$fortowner = %object;
      say("everybody", 0, getHudName($fortowner)@ " has occupied the Omega Construct!", "sfx_siren.WAV");
	giveTurretsToThisGuy(%object);
	schedule("retractBridge();", 0.25);
}

function Fortify::trigger::OnContact(%this, %object)
{
      %player = playerManager::vehicleIdToPlayerNum(%object);
	%team = getTeam(%object);
	if( %object != $fortowner ) return 0; // shouldn't happen, but just in case
	%player.occPoints = %player.occPoints + $occPoints;
	if(%team == *IDSTR_TEAM_RED) $redBonus = $redBonus + $occPoints;
	if(%team == *IDSTR_TEAM_BLUE) $blueBonus = $blueBonus + $occPoints;
}

function Fortify::trigger::OnLeave(%this, %object)
{
	if( %object == $fortowner ) schedule("neutralizefort();", 2);
}

function vehicle::onDestroyed(%destroyed, %destroyer)
{
   if( %destroyed == $fortowner ) schedule("neutralizefort();", 2);
	
   %team = getTeam(%destroyer);

   if(getHUDName(%destroyer) == "Omega Construct") {
	if(%team == *IDSTR_TEAM_RED) {
	   $redBonus = $redBonus + 3;
	   $redTK += 1;
	   }
	else if(%team == *IDSTR_TEAM_BLUE) {
	   $blueBonus = $blueBonus + 3;
	   $blueTK += 1;
	   }
   }
   
   if(%destroyed != %destroyer) {
	if(%destroyed == $fortowner) {
         %player = playerManager::vehicleIdToPlayerNum(%destroyer);
   	   %player.occKills += 1;
	   if(%team == *IDSTR_TEAM_RED) $redoccKills += 1;
	   else if(%team == *IDSTR_TEAM_BLUE) $blueoccKills += 1;
	   }
	}

   // Taken from DMStdLib.cs 

   // left over from missionStdLib.cs
   vehicle::onDestroyedLog(%destroyed, %destroyer);
   
   // this is weird but %destroyer isn't necessarily a vehicle
   %message = getFancyDeathMessage(getHUDName(%destroyed), getHUDName(%destroyer));
   if(%message != "")
   {
      say( 0, 0, %message);
   }
   
   // enforce the rules
   if($server::TeamPlay == true)
   {
      if((getTeam(%destroyed) == getTeam(%destroyer)) &&
         (%destroyed != %destroyer) ) {
         antiTeamKill(%destroyer);
      }
   }  
}

function neutralizefort()
{
	if($fortowner == "") return 0;
      say("everybody", 0, "The Omega Construct is unoccupied!", "sfx_cybrid_alarm.WAV");
	$fortowner = "";
	schedule("makeTurretsNeutral();", 2);
	extendBridge();
}

function retractBridge() 
{
	%target = getObjectId("MissionGroup\\CenterStructures\\BBridge1");

      schedule("moveBridge("@%target@", 700, 177.5,  4);", 0.1 );
      schedule("moveBridge("@%target@", 710, 167.5,  9);", 0.2 );
      schedule("moveBridge("@%target@", 721, 158.5, 15);", 0.3 );
      schedule("moveBridge("@%target@", 768, 162.5, 22);", 0.4 );
      schedule("moveBridge("@%target@", 801, 170,   30);", 0.5 );
      schedule("moveBridge("@%target@", 823, 180,   39);", 0.6 );
      schedule("moveBridge("@%target@", 841, 195,   49);", 0.7 );
      schedule("moveBridge("@%target@", 851, 210,   60);", 0.8 );
      schedule("moveBridge("@%target@", 857, 235,   73);", 0.9 );
      schedule("moveBridge("@%target@", 850, 265,   90);", 1.0 );
      schedule("moveBridge("@%target@", 850, 228,   90);", 1.1 );
      schedule("moveBridge("@%target@", 850, 191,   90);", 1.2 );
      schedule("moveBridge("@%target@", 850, 154,   90);", 1.3 );
      schedule("moveBridge("@%target@", 850, 117,   90);", 1.4 );
      schedule("moveBridge("@%target@", 850, 80,    90);", 1.5 );	

	%target = getObjectId("MissionGroup\\CenterStructures\\RBridge1");

      schedule("moveBridge("@%target@", 355, 177.5,  -4);", 0.1 );
      schedule("moveBridge("@%target@", 345, 167.5,  -9);", 0.2 );
      schedule("moveBridge("@%target@", 334, 158.5, -15);", 0.3 );
      schedule("moveBridge("@%target@", 287, 162.5, -22);", 0.4 );
      schedule("moveBridge("@%target@", 254, 170,   -30);", 0.5 );
      schedule("moveBridge("@%target@", 232, 180,   -39);", 0.6 );
      schedule("moveBridge("@%target@", 214, 195,   -49);", 0.7 );
      schedule("moveBridge("@%target@", 204, 210,   -60);", 0.8 );
      schedule("moveBridge("@%target@", 198, 235,   -73);", 0.9 );
      schedule("moveBridge("@%target@", 205, 265,   -90);", 1.0 );
      schedule("moveBridge("@%target@", 205, 228,   -90);", 1.1 );
      schedule("moveBridge("@%target@", 205, 191,   -90);", 1.2 );
      schedule("moveBridge("@%target@", 205, 154,   -90);", 1.3 );
      schedule("moveBridge("@%target@", 205, 117,   -90);", 1.4 );
      schedule("moveBridge("@%target@", 205, 80,    -90);", 1.5 );	

	%target = getObjectId("MissionGroup\\CenterStructures\\EBridge1");

      schedule("moveSideBridge("@%target@", 125, 177.5,  -4);", 0.1 );
      schedule("moveSideBridge("@%target@", 135, 167.5,  -9);", 0.2 );
      schedule("moveSideBridge("@%target@", 146, 158.5, -15);", 0.3 );
      schedule("moveSideBridge("@%target@", 193, 162.5, -22);", 0.4 );
      schedule("moveSideBridge("@%target@", 226, 170,   -30);", 0.5 );
      schedule("moveSideBridge("@%target@", 248, 180,   -39);", 0.6 );
      schedule("moveSideBridge("@%target@", 266, 195,   -49);", 0.7 );
      schedule("moveSideBridge("@%target@", 276, 210,   -60);", 0.8 );
      schedule("moveSideBridge("@%target@", 282, 235,   -73);", 0.9 );
      schedule("moveSideBridge("@%target@", 275, 265,   -90);", 1.0 );
      schedule("moveSideBridge("@%target@", 275, 228,   -90);", 1.1 );
      schedule("moveSideBridge("@%target@", 275, 191,   -90);", 1.2 );
      schedule("moveSideBridge("@%target@", 275, 154,   -90);", 1.3 );
      schedule("moveSideBridge("@%target@", 275, 117,   -90);", 1.4 );
      schedule("moveSideBridge("@%target@", 275, 80,    -90);", 1.5 );		

	%target = getObjectId("MissionGroup\\CenterStructures\\WBridge1");

      schedule("moveSideBridge("@%target@", -220, 177.5,  4);", 0.1 );
      schedule("moveSideBridge("@%target@", -230, 167.5,  9);", 0.2 );
      schedule("moveSideBridge("@%target@", -241, 158.5, 15);", 0.3 );
      schedule("moveSideBridge("@%target@", -288, 162.5, 22);", 0.4 );
      schedule("moveSideBridge("@%target@", -321, 170,   30);", 0.5 );
      schedule("moveSideBridge("@%target@", -343, 180,   39);", 0.6 );
      schedule("moveSideBridge("@%target@", -361, 195,   49);", 0.7 );
      schedule("moveSideBridge("@%target@", -371, 210,   60);", 0.8 );
      schedule("moveSideBridge("@%target@", -377, 235,   73);", 0.9 );
      schedule("moveSideBridge("@%target@", -370, 265,   90);", 1.0 );
      schedule("moveSideBridge("@%target@", -370, 228,   90);", 1.1 );
      schedule("moveSideBridge("@%target@", -370, 191,   90);", 1.2 );
      schedule("moveSideBridge("@%target@", -370, 154,   90);", 1.3 );
      schedule("moveSideBridge("@%target@", -370, 117,   90);", 1.4 );
      schedule("moveSideBridge("@%target@", -370, 80,    90);", 1.5 );	
}

function extendBridge() 
{
	%target = getObjectId("MissionGroup\\CenterStructures\\BBridge1");

      schedule("moveBridge("@%target@", 690, 187.5,  0);", 2.0 );
      schedule("moveBridge("@%target@", 700, 177.5,  4);", 1.85 );
      schedule("moveBridge("@%target@", 710, 167.5,  9);", 1.7 );
      schedule("moveBridge("@%target@", 721, 158.5, 15);", 1.55 );
      schedule("moveBridge("@%target@", 768, 162.5, 22);", 1.4 );
      schedule("moveBridge("@%target@", 801, 170,   30);", 1.25 );
      schedule("moveBridge("@%target@", 823, 180,   39);", 1.1 );
      schedule("moveBridge("@%target@", 841, 195,   49);", 0.95 );
      schedule("moveBridge("@%target@", 851, 210,   60);", 0.8 );
      schedule("moveBridge("@%target@", 857, 235,   73);", 0.65 );
      schedule("moveBridge("@%target@", 850, 265,   90);", 0.5 );
      schedule("moveBridge("@%target@", 850, 228,   90);", 0.4 );
      schedule("moveBridge("@%target@", 850, 191,   90);", 0.3 );
      schedule("moveBridge("@%target@", 850, 154,   90);", 0.2 );
      schedule("moveBridge("@%target@", 850, 117,   90);", 0.1 );
 	
	%target = getObjectId("MissionGroup\\CenterStructures\\RBridge1");

      schedule("moveBridge("@%target@", 365, 187.5,   0);", 2.0 );
      schedule("moveBridge("@%target@", 355, 177.5,  -4);", 1.85 );
      schedule("moveBridge("@%target@", 345, 167.5,  -9);", 1.7 );
      schedule("moveBridge("@%target@", 334, 158.5, -15);", 1.55 );
      schedule("moveBridge("@%target@", 287, 162.5, -22);", 1.4 );
      schedule("moveBridge("@%target@", 254, 170,   -30);", 1.25 );
      schedule("moveBridge("@%target@", 232, 180,   -39);", 1.1 );
      schedule("moveBridge("@%target@", 214, 195,   -49);", 0.95 );
      schedule("moveBridge("@%target@", 204, 210,   -60);", 0.8 );
      schedule("moveBridge("@%target@", 198, 235,   -73);", 0.65 );
      schedule("moveBridge("@%target@", 205, 265,   -90);", 0.5 );
      schedule("moveBridge("@%target@", 205, 225,   -90);", 0.4 );
      schedule("moveBridge("@%target@", 205, 191,   -90);", 0.3 );
      schedule("moveBridge("@%target@", 205, 154,   -90);", 0.2 );
      schedule("moveBridge("@%target@", 205, 117,   -90);", 0.1 );

	%target = getObjectId("MissionGroup\\CenterStructures\\EBridge1");

      schedule("moveSideBridge("@%target@", 115, 187.5,   0);", 2.0 );
      schedule("moveSideBridge("@%target@", 125, 177.5,  -4);", 1.85 );
      schedule("moveSideBridge("@%target@", 135, 167.5,  -9);", 1.7 );
      schedule("moveSideBridge("@%target@", 146, 158.5, -15);", 1.55 );
      schedule("moveSideBridge("@%target@", 193, 162.5, -22);", 1.4 );
      schedule("moveSideBridge("@%target@", 226, 170,   -30);", 1.25 );
      schedule("moveSideBridge("@%target@", 248, 180,   -39);", 1.1 );
      schedule("moveSideBridge("@%target@", 266, 195,   -49);", 0.95 );
      schedule("moveSideBridge("@%target@", 276, 210,   -60);", 0.8 );
      schedule("moveSideBridge("@%target@", 282, 235,   -73);", 0.65 );
      schedule("moveSideBridge("@%target@", 275, 265,   -90);", 0.5 );
      schedule("moveSideBridge("@%target@", 275, 228,   -90);", 0.4 );
      schedule("moveSideBridge("@%target@", 275, 191,   -90);", 0.3 );
      schedule("moveSideBridge("@%target@", 275, 154,   -90);", 0.2 );
      schedule("moveSideBridge("@%target@", 275, 117,   -90);", 0.1 );

	%target = getObjectId("MissionGroup\\CenterStructures\\WBridge1");

      schedule("moveSideBridge("@%target@", -210, 187.5,  0);", 2.0 );
      schedule("moveSideBridge("@%target@", -220, 177.5,  4);", 1.85 );
      schedule("moveSideBridge("@%target@", -230, 167.5,  9);", 1.7 );
      schedule("moveSideBridge("@%target@", -241, 158.5, 15);", 1.55 );
      schedule("moveSideBridge("@%target@", -288, 162.5, 22);", 1.4 );
      schedule("moveSideBridge("@%target@", -321, 170,   30);", 1.25 );
      schedule("moveSideBridge("@%target@", -343, 180,   39);", 1.1 );
      schedule("moveSideBridge("@%target@", -361, 195,   49);", 0.95 );
      schedule("moveSideBridge("@%target@", -371, 210,   60);", 0.8 );
      schedule("moveSideBridge("@%target@", -377, 235,   73);", 0.65 );
      schedule("moveSideBridge("@%target@", -370, 265,   90);", 0.5 );
      schedule("moveSideBridge("@%target@", -370, 228,   90);", 0.4 );
      schedule("moveSideBridge("@%target@", -370, 191,   90);", 0.3 );
      schedule("moveSideBridge("@%target@", -370, 154,   90);", 0.2 );
      schedule("moveSideBridge("@%target@", -370, 117,   90);", 0.1 );
}

function moveBridge(%bridge, %y, %z, %xrot)
{
	setPosition(%bridge, -47.5, %y, %z, 0, %xrot);
}

function moveSideBridge(%bridge, %x, %z, %xrot)
{
	setPosition(%bridge, %x, 527.5, %z, 90, %xrot);
}

function rejectvehicle(%object)
{
      %chx = -47.5 - getPosition(%object,x);
      %chy = 527.5 - getPosition(%object,y);

	%x = -47.5 - 2 * %chx;
	%y = 527.5 - 2 * %chy;
      %z = getPosition(%object,z) + 5;
	
      setPosition(%object, %x, %y, %z);

      %player = playerManager::vehicleIdToPlayerNum(%object);
      say(%player, 0, "sfx_cybrid_alarm.WAV");
}



// Laser Beams...



function Zap::trigger::OnEnter(%this, %object)
{
      healObject(%object, -10000);
	healObject(%object, -10000);
	healObject(%object, -10000);
	healObject(%object, -10000);
	healObject(%object, -10000);
      say("everyone", 0, "Ouch! " @ getHudName( %object ) @ " probably shouldn't have touched that!","sfx_electrical_bzzt.WAV");
}



// Turret Code
// -----------------------------------------------------------------------------------



function giveTurretsToThisGuy(%vehicleId){
	%team = getTeam(%vehicleId);
	setTeam("MissionGroup\\CenterStructures\\T1", %team);
	setTeam("MissionGroup\\CenterStructures\\T2", %team);
	setTeam("MissionGroup\\CenterStructures\\T3", %team);
	setTeam("MissionGroup\\CenterStructures\\T4", %team);
	setTeam("MissionGroup\\CenterStructures\\T5", %team);

	order("MissionGroup\\CenterStructures", Shutdown, false);

	%target = getObjectId("MissionGroup\\CenterStructures\\H1");
	playAnimSequence(%target, 0, true);
	schedule("LowerPod("@%target@");", 3 );

	%target = getObjectId("MissionGroup\\CenterStructures\\H2");
	playAnimSequence(%target, 0, true);
	schedule("LowerPod("@%target@");", 3 );

	%target = getObjectId("MissionGroup\\CenterStructures\\H3");
	playAnimSequence(%target, 0, true);
	schedule("LowerPod("@%target@");", 3 );

	%target = getObjectId("MissionGroup\\CenterStructures\\H4");
	playAnimSequence(%target, 0, true);
	schedule("LowerPod("@%target@");", 3 );
}

function makeTurretsNeutral(){
	setTeam("MissionGroup\\CenterStructures\\T1", 0);
	setTeam("MissionGroup\\CenterStructures\\T2", 0);
	setTeam("MissionGroup\\CenterStructures\\T3", 0);
	setTeam("MissionGroup\\CenterStructures\\T4", 0);
	setTeam("MissionGroup\\CenterStructures\\T5", 0);

	order("MissionGroup\\CenterStructures", Shutdown, true);	

	%target = getObjectId("MissionGroup\\CenterStructures\\H1");
	RaisePod(%target);
	schedule("ClosePod("@%target@");", 1 );
	
	%target = getObjectId("MissionGroup\\CenterStructures\\H2");
	RaisePod(%target);
	schedule("ClosePod("@%target@");", 1.5 );
	
	%target = getObjectId("MissionGroup\\CenterStructures\\H3");
	RaisePod(%target);
	schedule("ClosePod("@%target@");", 2 );
	
	%target = getObjectId("MissionGroup\\CenterStructures\\H4");
	RaisePod(%target);
	schedule("ClosePod("@%target@");", 2.5 );
}

function ClosePod(%this)
{
	playAnimSequence(%this, 0, false);
}

function LowerPod(%this)
{
	%x = getPosition(%this,x);
	%y = getPosition(%this,y);
	setposition(%this, %x, %y, 0);
}

function RaisePod(%this)
{
	%x = getPosition(%this,x);
	%y = getPosition(%this,y);
	setposition(%this, %x, %y, 135);
}



//------------------------------------------------------------------------------
// scoreboard 



function getPlayerScore(%a)
{
   %p = (getAdjKills(%a)*$killPoints)-(getDeaths(%a)*$deathPoints)+(%a.occKills*$occKillPoints)+%a.occPoints;
   return (%p);
}

function getAdjKills(%a)
{
   return (getKills(%a) - %a.occKills);
}

function getOccPoints(%a)
{
	return(%a.occPoints);
}

function getOccKills(%a)
{
	return(%a.occKills);
}

function getTeamTurretKills(%team)
{
	%teamname = getTeamNameFromTeamId(%team);
	if(%teamname == *IDSTR_TEAM_RED) 
	{
		return($redTK);
	}
	if(%teamname == *IDSTR_TEAM_BLUE) 
	{
		return($blueTK);
	}

	return 0;
}

function getTeamScore(%team)
{
   %teamname = getTeamNameFromTeamId(%team);
   if(%teamname == *IDSTR_TEAM_RED) 
   {
	%p = $redBonus+(getAdjTeamKills(%team)*$killPoints)-(getTeamDeaths(%team)*$deathPoints)+($redoccKills*$occKillPoints);
	return(%p);
   }
   if(%teamname == *IDSTR_TEAM_BLUE) 
   {
	%p = $blueBonus+(getAdjTeamKills(%team)*$killPoints)-(getTeamDeaths(%team)*$deathPoints)+($blueoccKills*$occKillPoints);
	return(%p);
   }

   return 0;
} 

function getAdjTeamKills(%team)
{
   %teamname = getTeamNameFromTeamId(%team);
   if(%teamname == *IDSTR_TEAM_RED) return (getTeamKills(%team) - $redoccKills);
   if(%teamname == *IDSTR_TEAM_BLUE) return (getTeamKills(%team) - $blueoccKills);
   else return 0;
}

function getTeamOccKills(%team)
{
   %teamname = getTeamNameFromTeamId(%team);
   if(%teamname == *IDSTR_TEAM_RED) return $redoccKills;
   if(%teamname == *IDSTR_TEAM_BLUE) return $blueoccKills;
   else return 0;
}

function initScoreBoard()
{
   deleteVariables("$ScoreBoard::PlayerColumn*");
   deleteVariables("$ScoreBoard::TeamColumn*");

   if($server::TeamPlay == "True")	
   {
	   // Player ScoreBoard column headings
	   $ScoreBoard::PlayerColumnHeader1 = *IDMULT_SCORE_TEAM;
	   $ScoreBoard::PlayerColumnHeader2 = *IDMULT_SCORE_SQUAD;
	   $ScoreBoard::PlayerColumnHeader3 = *IDMULT_SCORE_SCORE;
	   $ScoreBoard::PlayerColumnHeader4 = *IDMULT_SCORE_KILLS;
	   $ScoreBoard::PlayerColumnHeader5 = *IDMULT_SCORE_DEATHS;
	   $ScoreBoard::PlayerColumnHeader6 = "Occ. Kills";
	   $ScoreBoard::PlayerColumnHeader7 = "Occ. Points";

	   // Player ScoreBoard column functions
	   $ScoreBoard::PlayerColumnFunction1 = "getTeam";
	   $ScoreBoard::PlayerColumnFunction2 = "getSquad";
	   $ScoreBoard::PlayerColumnFunction3 = "getPlayerScore";
	   $ScoreBoard::PlayerColumnFunction4 = "getKills";
	   $ScoreBoard::PlayerColumnFunction5 = "getDeaths";
	   $ScoreBoard::PlayerColumnFunction6 = "getOccKills";
	   $ScoreBoard::PlayerColumnFunction7 = "getOccPoints";
   }
   else
   {
       // Player ScoreBoard column headings
	   $ScoreBoard::PlayerColumnHeader1 = *IDMULT_SCORE_SQUAD;
	   $ScoreBoard::PlayerColumnHeader2 = *IDMULT_SCORE_SCORE;
	   $ScoreBoard::PlayerColumnHeader3 = *IDMULT_SCORE_KILLS;
	   $ScoreBoard::PlayerColumnHeader4 = *IDMULT_SCORE_DEATHS;

	   // Player ScoreBoard column functions
	   $ScoreBoard::PlayerColumnFunction1 = "getSquad";
	   $ScoreBoard::PlayerColumnFunction2 = "getPlayerScore";
	   $ScoreBoard::PlayerColumnFunction3 = "getKills";
	   $ScoreBoard::PlayerColumnFunction4 = "getDeaths";
   }

   // Team ScoreBoard column headings
   $ScoreBoard::TeamColumnHeader1 = *IDMULT_SCORE_SCORE;
   $ScoreBoard::TeamColumnHeader2 = *IDMULT_SCORE_PLAYERS;
   $ScoreBoard::TeamColumnHeader3 = *IDMULT_SCORE_KILLS;
   $ScoreBoard::TeamColumnHeader4 = *IDMULT_SCORE_DEATHS;
   $ScoreBoard::TeamColumnHeader5 = "Turret Kills";
   $ScoreBoard::TeamColumnHeader6 = "Occ. Kills";

   // Team ScoreBoard column functions
   $ScoreBoard::TeamColumnFunction1 = "getTeamScore";
   $ScoreBoard::TeamColumnFunction2 = "getNumberOfPlayersOnTeam";
   $ScoreBoard::TeamColumnFunction3 = "getAdjTeamKills";
   $ScoreBoard::TeamColumnFunction4 = "getTeamDeaths";
   $ScoreBoard::TeamColumnFunction5 = "getTeamTurretKills";
   $ScoreBoard::TeamColumnFunction6 = "getTeamOccKills";

   // tell server to process all the scoreboard definitions defined above
   serverInitScoreBoard();
}